@@ -25,11 +25,13 @@ SEL_COLUMN = 1
 CARET_SET_ONE    = 0
 CARET_ADD        = 1
 CARET_DELETE_ALL = 2
+CARET_SORT       = 3
 CARET_SET_INDEX  = 100
 CARET_DELETE_INDEX = 2000000
 
 CARET_OPTION_NO_SCROLL = 1
-CARET_OPTION_NO_EVENT = 2
+CARET_OPTION_NO_EVENT = 1 << 1
+CARET_OPTION_NO_SORT = 1 << 2
 
 APP_DIR_EXE             = 0
 APP_DIR_SETTINGS        = 1
@@ -51,7 +53,6 @@ CONVERT_PIXELS_TO_CARET     = 7
 CONVERT_CARET_TO_PIXELS     = 8
 
 TOKEN_GET_KIND = 1
-TOKEN_LIST     = 2
 TOKEN_LIST_SUB = 3
 
 LINESTATE_NORMAL  = 0
@@ -108,19 +109,15 @@ BOOKMARK_SET         = 1
 BOOKMARK_CLEAR       = 2
 BOOKMARK_CLEAR_ALL   = 3
 BOOKMARK_SETUP       = 4
-BOOKMARK_GET_LIST    = 5
 BOOKMARK_GET_ALL     = 6
-BOOKMARK_GET_PROP      = 7
 BOOKMARK_DELETE_BY_TAG = 8
 
 BOOKMARK2_SET         = 11
 BOOKMARK2_CLEAR       = 12
 BOOKMARK2_CLEAR_ALL   = 13
 BOOKMARK2_GET_ALL     = 16
-BOOKMARK2_GET_PROP      = 17
 BOOKMARK2_DELETE_BY_TAG = 18
 
-MARKERS_GET           = 0
 MARKERS_ADD           = 1
 MARKERS_DELETE_ALL    = 2
 MARKERS_DELETE_LAST   = 3
@@ -131,6 +128,7 @@ MARKERS_GET_DICT      = 7
 MARKERS_DELETE_BY_POS = 8
 MARKERS_GET_DUPS      = 14
 MARKERS_SET_DUPS      = 15
+MARKERS_SET_SORTED    = 16
 
 TIMER_START     = 0
 TIMER_START_ONE = 1
@@ -309,6 +307,7 @@ PROP_MINIMAP_SCALE      = 162
 PROP_TAB_TITLE_REASON   = 163
 PROP_RULER_TEXT         = 164
 PROP_UNPRINTED_WRAPS    = 165
+PROP_LEXER_BUSY         = 166
 
 PROP_CORNER_TEXT          = 170
 PROP_CORNER_COLOR_FONT    = 171
@@ -348,7 +347,6 @@ PROC_SET_SESSION         = 5
 PROC_GET_CLIP_EX         = 6
 PROC_SET_FOLDER          = 7
 PROC_GET_COMMANDS        = 8
-PROC_SET_EVENTS          = 10
 PROC_GET_LAST_PLUGIN     = 11
 PROC_GET_GROUPING        = 12
 PROC_SET_GROUPING        = 13
@@ -358,6 +356,9 @@ PROC_SET_SUBCOMMANDS     = 16
 PROC_GET_ESCAPE          = 17
 PROC_SET_ESCAPE          = 18
 PROC_PARSE_COMMAND_LINE  = 19
+PROC_EVENTS_SUB          = 20
+PROC_EVENTS_UNSUB        = 21
+PROC_EVENTS_ENUM         = 22
 #
 PROC_SIDEPANEL_ACTIVATE    = 25
 PROC_SIDEPANEL_GET_CONTROL = 27
@@ -401,6 +402,7 @@ PROC_GET_VALIDATE_FORM = 65
 PROC_GET_MAIN_TOOLBAR   = 66
 PROC_GET_MAIN_STATUSBAR = 67
 PROC_GET_CODETREE_CURRENT_NODE = 68
+PROC_GET_CODETREE_FILTER = 69
 #
 PROC_BOTTOMPANEL_ACTIVATE    = 81
 PROC_BOTTOMPANEL_GET_CONTROL = 83
@@ -468,7 +470,6 @@ PROC_CONFIG_SCALE_SET      = 176
 PROC_CONFIG_HISTORY_SAVE   = 177
 
 TREE_ITEM_ENUM_EX          = 0
-TREE_ITEM_ENUM             = 1
 TREE_ITEM_ADD              = 2
 TREE_ITEM_DELETE           = 3
 TREE_ITEM_SET_TEXT         = 4
@@ -495,13 +496,15 @@ TREE_PROP_SHOW_ROOT        = 30
 TREE_LOCK                  = 31
 TREE_UNLOCK                = 32
 TREE_THEME                 = 33
+TREE_GET_SCROLLSTYLE_HORZ  = 40
+TREE_SET_SCROLLSTYLE_HORZ  = 41
+TREE_GET_SCROLLSTYLE_VERT  = 42
+TREE_SET_SCROLLSTYLE_VERT  = 43
 
 LISTBOX_GET_COUNT    = 0
 LISTBOX_ADD          = 1
 LISTBOX_DELETE       = 2
 LISTBOX_DELETE_ALL   = 3
-LISTBOX_GET_ITEM     = 4
-LISTBOX_SET_ITEM     = 5
 LISTBOX_GET_HOTTRACK = 6
 LISTBOX_SET_HOTTRACK = 7
 LISTBOX_GET_ITEM_PROP = 8
@@ -534,6 +537,7 @@ LISTBOX_GET_HEADER_IMAGELIST = 38
 LISTBOX_SET_HEADER_IMAGELIST = 39
 LISTBOX_GET_HEADER_IMAGEINDEXES = 40
 LISTBOX_SET_HEADER_IMAGEINDEXES = 41
+LISTBOX_SET_DISABLING_CHAR = 43
 
 SCROLLSTYLE_HIDE = 0
 SCROLLSTYLE_SHOW = 1
@@ -576,6 +580,8 @@ EDACTION_SHOW_POS       = 9
 EDACTION_CODETREE_FILL  = 10
 EDACTION_LEXER_SCAN     = 11
 EDACTION_APPLY_THEME    = 12
+EDACTION_LOCK           = 13
+EDACTION_UNLOCK         = 14
 EDACTION_EXPORT_HTML    = 15
 
 MICROMAP_GET    = 0
@@ -595,6 +601,8 @@ APPSTATE_API_SUBCOMMANDS    = 30
 APPSTATE_API_MENU_ADD       = 31
 APPSTATE_API_MENU_REMOVE    = 32
 APPSTATE_API_MENU_CHANGE    = 33
+APPSTATE_TAB_SPLIT          = 34
+APPSTATE_TAB_SPLIT_V_H      = 35
 APPSTATE_WINDOW             = 39
 
 APPSTATE_CODETREE_CLEAR         = 40
@@ -604,6 +612,11 @@ APPSTATE_CODETREE_SET_SELECTION = 43
 APPSTATE_CODETREE_DBL_CLICK     = 44
 APPSTATE_CODETREE_BEFORE_CLEAR  = 45
 APPSTATE_CODETREE_FOLDED_UNFOLDED = 46
+APPSTATE_CODETREE_FILTER_CHANGE = 47
+
+APPSTATE_CLEAR_HISTORY_RECENTS = 53
+APPSTATE_CLEAR_HISTORY_FINDER  = 54
+APPSTATE_CLEAR_HISTORY_CONSOLE = 55
 
 EDSTATE_WRAP      = 1
 EDSTATE_TAB_TITLE = 2
@@ -973,7 +986,6 @@ DBORDER_TOOL     = 4
 DBORDER_TOOLSIZE = 5
 
 DECOR_GET_ALL          = 0
-DECOR_GET              = 1
 DECOR_SET              = 2
 DECOR_DELETE_BY_LINE   = 5
 DECOR_DELETE_BY_TAG    = 6
@@ -1024,6 +1036,37 @@ HINTPOS_TEXT_BRACKET  = 3
 HINTPOS_WINDOW_TOP    = 8
 HINTPOS_WINDOW_BOTTOM = 9
 
+CURSOR_DEFAULT      = 0
+CURSOR_NONE         = -1
+CURSOR_ARROW        = -2
+CURSOR_CROSS        = -3
+CURSOR_I_BEAM       = -4
+CURSOR_SIZE_NESW    = -6
+CURSOR_SIZE_NS      = -7
+CURSOR_SIZE_NWSE    = -8
+CURSOR_SIZE_WE      = -9
+CURSOR_UP_ARROW     = -10
+CURSOR_HOURGLASS    = -11
+CURSOR_DRAG         = -12
+CURSOR_NO_DROP      = -13
+CURSOR_H_SPLIT      = -14
+CURSOR_V_SPLIT      = -15
+CURSOR_MULTI_DRAG   = -16
+CURSOR_SQL_WAIT     = -17
+CURSOR_NO           = -18
+CURSOR_APP_START    = -19
+CURSOR_HELP         = -20
+CURSOR_HAND_POINT   = -21
+CURSOR_SIZE_ALL     = -22
+CURSOR_SIZE_NW      = -23
+CURSOR_SIZE_N       = -24
+CURSOR_SIZE_NE      = -25
+CURSOR_SIZE_W       = -26
+CURSOR_SIZE_E       = -27
+CURSOR_SIZE_SW      = -28
+CURSOR_SIZE_S       = -29
+CURSOR_SIZE_SE      = -30
+
 API, EXE_VER = ct.app_ver()
 
 def app_exe_version():
@@ -1129,7 +1172,7 @@ def dlg_custom(title, size_x, size_y, text, focused=-1, get_dict=False):
     if not get_dict:
         return res
     else:
-        return _dlg_custom_dict(res, count=len(text.splitlines()) )
+        return _dlg_custom_dict(res, count=len(text.split('\n')) )
 
 def file_open(name, group=-1, options=''):
     if isinstance(name, (list, tuple)):
@@ -1386,6 +1429,9 @@ class Editor:
     def save(self, filename='', as_copy=False):
         return ct.ed_save(self.h, filename, as_copy)
 
+    def load(self, filename):
+        return ct.ed_load(self.h, filename)
+
     def cmd(self, code, text=''):
         return ct.ed_cmd(self.h, code, esc_z(text))
 
